@@ -36,7 +36,7 @@ Q_PROPERTY(quint64 ratingCount READ ratingCount CONSTANT)
 public:
     explicit Rating(const QVariantMap &data);
     explicit Rating(const QString& packageName, quint64 ratingCount, int rating, const QString& histogram);
-    explicit Rating(QString packageName, int inst, int vote, int old, int recent);
+    explicit Rating(QString packageName, int inst);
     ~Rating() override;
 
     QString packageName() const;
@@ -48,10 +48,9 @@ public:
     double sortableRating() const;
 
 private:
-    void init(const QString& packageName, quint64 ratingCount, int rating, const QString& histogram);
-    QString m_packageName;
-    quint64 m_ratingCount;
-    int m_rating;
+    const QString m_packageName;
+    const quint64 m_ratingCount;
+    const int m_rating;
     int m_ratingPoints;
     double m_sortableRating;
 };
