@@ -27,8 +27,8 @@ class DiscoverDeclarativePlugin : public QQmlExtensionPlugin
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
     public:
-        virtual void initializeEngine(QQmlEngine* engine, const char* uri) override;
-        virtual void registerTypes(const char*) override;
+        void initializeEngine(QQmlEngine* engine, const char* uri) override;
+        void registerTypes(const char* /*uri*/) override;
 };
 
 #endif
