@@ -28,7 +28,7 @@ class DISCOVERNOTIFIERS_EXPORT BackendNotifierModule : public QObject
 {
 Q_OBJECT
 public:
-    BackendNotifierModule(QObject* parent = nullptr);
+    explicit BackendNotifierModule(QObject* parent = nullptr);
     ~BackendNotifierModule() override;
 
     /*** @returns \c true if there are any updates, \c false if not **/
